%ifarch x86_64
%bcond_with check
%endif
%global goipath         github.com/containerd

Summary:        An industry-standard container runtime
Name:           containerd
Version:        1.7.3
Release:        7%{?dist}
License:        ASL 2.0
URL:            https://containerd.io
Source0:        https://github.com/containerd/containerd/archive/refs/tags/v%{version}.tar.gz
Source1:        containerd.toml
Patch5000:	0001-add-loong64-support-for-cilium.patch

BuildRequires:  golang glibc-static make btrfs-progs-devel git systemd-rpm-macros
BuildRequires:  go-rpm-macros go-md2man
Requires:       runc
Provides:       containerd.io = %{version}-%{release}

%description
containerd is an industry-standard container runtime with an emphasis on
simplicity, robustness and portability.  It is available as a daemon for Linux
and Windows, which can manage the complete container lifecycle of its host
system: image transfer and storage, container execution and supervision,
low-level storage and network attachments, etc.

%prep
%autosetup -n %{name}-%{version} -p1 -Sgit
sed -i "s|/usr/local/bin/containerd|/usr/bin/containerd|" containerd.service

%build
export LDFLAGS="-X %{goipath}/containerd/version.Version=%{version} "
export GOPATH="$PWD/.gopath"
mkdir -p $GOPATH/src/%{goipath}
ln -sfn $PWD $GOPATH/src/%{goipath}/containerd
for cmd in cmd/* ; do
    %gobuild -o bin/$(basename $cmd) %{goipath}/containerd/$cmd
done

mkdir _man
go-md2man -in docs/man/containerd-config.8.md -out _man/containerd-config.8
go-md2man -in docs/man/containerd-config.toml.5.md -out _man/containerd-config.toml.5
bin/gen-manpages containerd.8 _man
bin/gen-manpages ctr.8 _man
rm -f bin/gen-manpages
rm -f bin/protoc-gen-go-fieldpath

%install
install -d %{buildroot}%{_bindir}
install -p -m 755 bin/* %{buildroot}%{_bindir}/
install -D -p -m 0644 _man/containerd.8 %{buildroot}%{_mandir}/man8/containerd.8
install -D -p -m 0644 _man/containerd-config.8 %{buildroot}%{_mandir}/man8/containerd-config.8
install -D -p -m 0644 _man/ctr.8 %{buildroot}%{_mandir}/man8/ctr.8
install -D -p -m 0644 _man/containerd-config.toml.5 %{buildroot}%{_mandir}/man5/containerd-config.toml.5
install -D -p -m 0644 containerd.service %{buildroot}%{_unitdir}/containerd.service
install -D -p -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/containerd/config.toml
mkdir -p %{buildroot}%{_sharedstatedir}/containerd/opt

%post
%systemd_post containerd.service

%preun
%systemd_preun containerd.service

%postun
%systemd_postun_with_restart containerd.service

%if %{with check}
%check
%gocheck -d pkg/cri/server -t integration -d platforms
%endif

%files
%license LICENSE NOTICE
%doc docs ROADMAP.md SCOPE.md code-of-conduct.md BUILDING.md
%doc README.md RELEASES.md
%{_unitdir}/containerd.service
%{_bindir}/*
%dir %{_sysconfdir}/containerd
%config(noreplace) %{_sysconfdir}/containerd/config.toml
%dir %{_sharedstatedir}/containerd
%dir %{_sharedstatedir}/containerd/opt
%{_mandir}/man8/containerd.8*
%{_mandir}/man8/containerd-config.8*
%{_mandir}/man8/ctr.8*
%{_mandir}/man5/containerd-config.toml.5*

%changelog
* Fri Feb 28 2025 Fanjun Kong <fanjunkong@tencent.com> - 1.7.3-7
- add provides for containerd.io

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.7.3-6
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.7.3-5
- Rebuilt for loongarch release

* Mon Mar 18 2024 Wenlong Zhang <zhangwenlong@loongson.cn> - 1.7.3-4
- add loongarch64 support for containerd

* Thu Dec 07 2023 jackeyji <jackeyji@tencent.com> - 1.7.3-3
- remove manual generation files

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.7.3-2
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 02 2023 jackeyji <jackeyji@tencent.com> - 1.7.3-1
- upgrade to 1.7.3

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.6.9-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.6.9-3
- Rebuilt for OpenCloudOS Stream 23

* Fri Dec 16 2022 Shuo Wang <abushwang@tencent.com> - 1.6.9-2
- enable debuginfo pkg

* Wed Dec 14 2022 Shuo Wang <abushwang@tencent.com> - 1.6.9-1
- initial build

